@@ -31,7 +31,7 @@ export class CreateForm extends FormAction {
   init() {
     this.store = globalImageStore;
     this.projectStore = new ProjectStore();
-    this.getProjects();
+    this.isAdminPage && this.getProjects();
   }
 
   static id = 'image-create';
@@ -72,10 +72,9 @@ export class CreateForm extends FormAction {
     return Promise.resolve(true);
   }
 
-  getProjects() {
-    if (this.isAdminPage) {
-      this.projectStore.fetchList();
-    }
+  async getProjects() {
+    await this.projectStore.fetchProjectsWithDomain();
+    this.updateDefaultValue();
   }
 
   get projects() {
@@ -347,12 +346,14 @@ export class CreateForm extends FormAction {
       owner,
       usage_type = 'common',
       members,
+      os_distro,
       ...rest
     } = values;
     const body = {
       visibility: visibility || 'private',
       container_format: 'bare',
       usage_type,
+      os_distro,
       ...rest,
     };
     if (min_ram) {
@@ -367,6 +368,9 @@ export class CreateForm extends FormAction {
     if (this.isAdminPage) {
       body.owner = owner.selectedRowKeys[0];
     }
+    if (os_distro === 'windows') {
+      body.os_type = 'windows';
+    }
     const mems = visibility === 'shared' ? members.selectedRowKeys : [];
     const config = this.getUploadRequestConf();
     const actualFile = uploadType === 'file' ? file : url;
