@@ -22,6 +22,7 @@ import globalProjectStore from 'stores/keystone/project';
 import classnames from 'classnames';
 import { isEmpty, isFinite, isString } from 'lodash';
 import { getUserData } from 'resources/nova/instance';
+import { getAllDataDisks } from 'resources/cinder/snapshot';
 import { getGiBValue } from 'utils/index';
 import Notify from 'components/Notify';
 import ConfirmStep from './ConfirmStep';
@@ -70,7 +71,7 @@ export class StepCreate extends StepAction {
     });
     await Promise.all([
       this.projectStore.fetchProjectNovaQuota(),
-      this.projectStore.fetchProjectCinderQuota(),
+      this.enableCinder ? this.projectStore.fetchProjectCinderQuota() : null,
     ]);
     this.setState({
       quotaLoading: false,
@@ -299,12 +300,14 @@ export class StepCreate extends StepAction {
       count = 1,
       source: { value: sourceValue } = {},
       instanceSnapshotDisk = {},
+      instanceSnapshotDataVolumes = [],
     } = data;
     const newCountMap = {};
     const newSizeMap = {};
     let totalNewCount = 0;
     let totalNewSize = 0;
-    if (sourceValue === 'instanceSnapshot' && instanceSnapshotDisk) {
+    const isSnapshotType = sourceValue === 'instanceSnapshot';
+    if (isSnapshotType && instanceSnapshotDisk) {
       const { size, typeOption: { label } = {} } = instanceSnapshotDisk;
       if (label) {
         newCountMap[label] = !newCountMap[label] ? 1 : newCountMap[label] + 1;
@@ -322,11 +325,19 @@ export class StepCreate extends StepAction {
       totalNewCount += 1 * count;
       totalNewSize += size * count;
     }
-    if (dataDisk) {
-      dataDisk.forEach((item) => {
-        if (item.value && item.value.type) {
-          const { size } = item.value;
-          const { label } = item.value.typeOption || {};
+    if (
+      dataDisk ||
+      (isSnapshotType && instanceSnapshotDataVolumes?.length > 0)
+    ) {
+      const allDataDisks = getAllDataDisks({
+        dataDisk,
+        instanceSnapshotDataVolumes,
+      });
+      allDataDisks.forEach((item) => {
+        const diskItem = item.value || {};
+        if (diskItem.type) {
+          const { size, typeOption } = diskItem;
+          const { label } = typeOption || {};
           newCountMap[label] = !newCountMap[label]
             ? 1 * count
             : newCountMap[label] + 1 * count;
@@ -507,9 +518,9 @@ export class StepCreate extends StepAction {
     return null;
   }
 
-  renderFooterLeft() {
+  getCountInputConfig() {
     const { data } = this.state;
-    const { count = 1, source: { value: sourceValue } = {} } = data;
+    const { source: { value: sourceValue } = {} } = data;
     const configs = {
       min: 1,
       max:
@@ -522,17 +533,30 @@ export class StepCreate extends StepAction {
       onChange: this.onCountChange,
       formatter: (value) => `$ ${value}`.replace(/\D/g, ''),
     };
+    return configs;
+  }
+
+  renderCountInput() {
+    const { data } = this.state;
+    const { count = 1 } = data || {};
+    const configs = this.getCountInputConfig();
+    return (
+      <div className={styles['number-input']}>
+        <span>{t('Count')}</span>
+        <InputNumber
+          {...configs}
+          value={count}
+          className={classnames(styles.input, 'instance-count')}
+        />
+      </div>
+    );
+  }
+
+  renderFooterLeft() {
     return (
       <div style={{ display: 'flex' }}>
         <div style={{ display: 'flex', alignItems: 'center' }}>
-          <div className={styles['number-input']}>
-            <span>{t('Count')}</span>
-            <InputNumber
-              {...configs}
-              value={count}
-              className={classnames(styles.input, 'instance-count')}
-            />
-          </div>
+          {this.renderCountInput()}
           {this.renderExtra()}
         </div>
         {this.renderBadge()}
